require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xvmharddiskdrive',
  dscmeta_resource_friendly_name: 'xVMHardDiskDrive',
  dscmeta_resource_name: 'MSFT_xVMHardDiskDrive',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xHyper-V',
  dscmeta_module_version: '3.18.0',
  docs: 'The DSC xVMHardDiskDrive resource type.
         Automatically generated from version 3.18.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Variant[String[1], Sensitive[String[1]]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies if the hard disk drive must be present or absent. If not specified, it defaults to Present.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_controllerlocation: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of the location on the controller where the disk is attached. If not specified, it defaults to 0.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_controllernumber: {
      type: "Optional[Enum['0', '1', '2', '3']]",
      desc: 'Specifies the number of the controller where the disk is attached. If not specified, it defaults to 0.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_vmname: {
      type: 'String',
      desc: 'Specifies the name of the virtual machine whose hard disk drive is to be manipulated.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'String',
      desc: 'Specifies the full path to the location of the VHD that represents the hard disk drive.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_controllertype: {
      type: "Optional[Enum['IDE', 'ide', 'SCSI', 'scsi']]",
      desc: 'Specifies the controller type - IDE/SCSI where the disk is attached. If not specified, it defaults to SCSI.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
