require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xvmhost',
  dscmeta_resource_friendly_name: 'xVMHost',
  dscmeta_resource_name: 'MSFT_xVMHost',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xHyper-V',
  dscmeta_module_version: '3.18.0',
  docs: 'The DSC xVMHost resource type.
         Automatically generated from version 3.18.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_fibrechannelwwpnminimum: {
      type: 'Optional[String]',
      desc: 'Specifies the minimum value that can be used to generate the World Wide Port Names on the Hyper-V host.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_numaspanningenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether virtual machines on the Hyper-V host can use resources from more than one NUMA node.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maximumvirtualmachinemigrations: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum number of live migrations that can be performed at the same time on the Hyper-V host.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_useanynetworkformigration: {
      type: 'Optional[Boolean]',
      desc: 'Specifies how networks are selected for incoming live migration traffic.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_macaddressminimum: {
      type: 'Optional[String]',
      desc: 'Specifies the minimum MAC address using a valid hexadecimal value.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Variant[String[1], Sensitive[String[1]]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_maximumstoragemigrations: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum number of storage migrations that can be performed at the same time on the Hyper-V host.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_virtualharddiskpath: {
      type: 'Optional[String]',
      desc: 'Specifies the default folder to store virtual hard disks on the Hyper-V host.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_virtualmachinepath: {
      type: 'Optional[String]',
      desc: 'Specifies the default folder to store virtual machine configuration files on the Hyper-V host.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_fibrechannelwwnn: {
      type: 'Optional[String]',
      desc: 'Specifies the default value of the World Wide Node Name on the Hyper-V host.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_virtualmachinemigrationauthenticationtype: {
      type: "Optional[Enum['CredSSP', 'credssp', 'Kerberos', 'kerberos']]",
      desc: "Specifies the type of authentication to be used for live migrations. The acceptable values for this parameter are 'Kerberos' and 'CredSSP'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enableenhancedsessionmode: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether users can use enhanced mode when they connect to virtual machines on this server by using Virtual Machine Connection.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_resourcemeteringsaveintervalminute: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how often the Hyper-V host saves the data that tracks resource usage. The range is a minimum of 60 minutes to a maximum of 1440 (24 hours).',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes', 'yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'.",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_macaddressmaximum: {
      type: 'Optional[String]',
      desc: 'Specifies the maximum MAC address using a valid hexadecimal value.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_virtualmachinemigrationperformanceoption: {
      type: "Optional[Enum['TCPIP', 'tcpip', 'Compression', 'compression', 'SMB', 'smb']]",
      desc: "Specifies the performance option to use for live migration. The acceptable values for this parameter are 'TCPIP', 'Compression' and 'SMB'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_fibrechannelwwpnmaximum: {
      type: 'Optional[String]',
      desc: 'Specifies the maximum value that can be used to generate World Wide Port Names on the Hyper-V host.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_virtualmachinemigrationenabled: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether Live Migration should be enabled or disabled on the Hyper-V host.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
