require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xvmprocessor',
  dscmeta_resource_friendly_name: 'xVMProcessor',
  dscmeta_resource_name: 'MSFT_xVMProcessor',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xHyper-V',
  dscmeta_module_version: '3.18.0',
  docs: 'The DSC xVMProcessor resource type.
         Automatically generated from version 3.18.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_restartifneeded: {
      type: 'Optional[Boolean]',
      desc: 'If specified, shutdowns and restarts the VM if needed for property changes.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maximumcountpernumanode: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum number of processors per NUMA node to be configured for the virtual machine.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_relativeweight: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: "Specifies the priority for allocating the physical computer's processing power to this virtual machine relative to others. Allowed values range from 1 to 10000.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_vmname: {
      type: 'String',
      desc: 'Specifies the name of the virtual machine on which the processor is to be configured.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Variant[String[1], Sensitive[String[1]]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_compatibilityformigrationenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the virtual processors features are to be limited for compatibility when migrating the virtual machine to another host.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_compatibilityforolderoperatingsystemsenabled: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether the virtual processorâ??s features are to be limited for compatibility with older operating systems.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_maximumcountpernumasocket: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the maximum number of sockets per NUMA node to be configured for the virtual machine.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_maximum: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'Specifies the maximum percentage of resources available to the virtual machine processor to be configured. Allowed values range from 0 to 100.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_hwthreadcountpercore: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'Specifies the maximum thread core per processor core.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_resourcepoolname: {
      type: 'Optional[String]',
      desc: 'Specifies the name of the processor resource pool to be used.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablehostresourceprotection: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether to enable host resource protection.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_reserve: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'Specifies the percentage of processor resources to be reserved for this virtual machine. Allowed values range from 0 to 100.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_exposevirtualizationextensions: {
      type: 'Optional[Boolean]',
      desc: 'Specifies whether nested virtualization is enabled.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
