require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xvmscsicontroller',
  dscmeta_resource_friendly_name: 'xVMScsiController',
  dscmeta_resource_name: 'MSFT_xVMScsiController',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xHyper-V',
  dscmeta_module_version: '3.18.0',
  docs: 'The DSC xVMScsiController resource type.
         Automatically generated from version 3.18.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_restartifneeded: {
      type: 'Optional[Boolean]',
      desc: 'Specifies if the VM should be restarted if needed for property changes. If not specified, it defaults to False.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_controllernumber: {
      type: "Enum['0', '1', '2', '3']",
      desc: 'Specifies the number of the SCSI controller whose status is to be controlled. If not specified, it defaults to 0.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_vmname: {
      type: 'String',
      desc: 'Specifies the name of the virtual machine whose SCSI controller status is to be controlled',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Variant[String[1], Sensitive[String[1]]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Specifies if the SCSI controller should exist or not. If not specified, it defaults to Present.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
