require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xvmswitch',
  dscmeta_resource_friendly_name: 'xVMSwitch',
  dscmeta_resource_name: 'MSFT_xVMSwitch',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xHyper-V',
  dscmeta_module_version: '3.18.0',
  docs: 'The DSC xVMSwitch resource type.
         Automatically generated from version 3.18.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of the VM Switch',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Variant[String[1], Sensitive[String[1]]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_type: {
      type: "Enum['External', 'external', 'Internal', 'internal', 'Private', 'private']",
      desc: 'Type of switch',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_id: {
      type: 'Optional[String]',
      desc: 'Unique ID for the switch (Only settable on Windows Server 2016!)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Whether switch should be present or absent',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_netadapterinterfacedescription: {
      type: 'Optional[String]',
      desc: 'Description of the network interface',

      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowmanagementos: {
      type: 'Optional[Boolean]',
      desc: 'Specify if the VM host has access to the physical NIC',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enableembeddedteaming: {
      type: 'Optional[Boolean]',
      desc: 'Should embedded NIC teaming be used (Windows Server 2016 only)',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_netadaptername: {
      type: 'Optional[Array[String]]',
      desc: 'Network adapter name(s) for external switch type',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_bandwidthreservationmode: {
      type: "Optional[Enum['Default', 'default', 'Weight', 'weight', 'Absolute', 'absolute', 'None', 'none', 'NA', 'na']]",
      desc: 'Type of Bandwidth Reservation Mode to use for the switch',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_loadbalancingalgorithm: {
      type: "Optional[Enum['Dynamic', 'dynamic', 'HyperVPort', 'hypervport']]",
      desc: 'Specifies the load balancing algorithm that this switch team uses',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
